from torch import nn
from huggingface_hub import PyTorchModelHubMixin


model_card_template = """
---
{{ card_data }}
---

This model has been pushed to the Hub using the [PytorchModelHubMixin](https://huggingface.co/docs/huggingface_hub/package_reference/mixins#huggingface_hub.PyTorchModelHubMixin) integration.

Library: [pxia]({{repo_url}})

## how to load
```
pip install pxia
```

```python
from pxia import Hannibal
model = Hannibal.from_pretrained("{{ repo_id | default("phxia/Hannibal") }}")
```

## Contributions
Any contributions are welcome at https://github.com/not-lain/pxia.

## Myth
A phoenix is a legendary creature that was part of the ancient Phoenician empire, known for its barbarian warriors who with their general Hannibal fought against the Roman empire.

<img src="https://huggingface.co/spaces/phxia/README/resolve/main/logo.png"/>

"""


class Hannibal(
    nn.Module,
    PyTorchModelHubMixin,
    library_name="pxia",
    repo_url="https://github.com/not-lain/pxia",
    tags=["visual-question-answering", "pxia", "hannibal"],
    model_card_template=model_card_template,
):
    """an AI model for visual question answering"""

    def __init__(self, a=2, b=1):
        super().__init__()
        self.layer = nn.Linear(a, b, bias=False)

    def forward(self, input_ids):
        return self.layer(input_ids)



import pathlib
from setuptools import find_packages, setup


# shamelessly stolen from https://github.com/huggingface/huggingface_hub/blob/main/setup.py
def get_version() -> str:
    rel_path = "src/pxia/__init__.py"
    with open(rel_path, "r") as fp:
        for line in fp.read().splitlines():
            if line.startswith("__version__"):
                delim = '"' if '"' in line else "'"
                return line.split(delim)[1]
    raise RuntimeError("Unable to find version string.")


with open("requirements.txt", "r", encoding="utf-8") as f:
    required = f.read().splitlines()

setup(
    name="pxia",
    version=get_version(),
    description="a repository for PXIA models",
    long_description=pathlib.Path("README.md").read_text(encoding="utf-8"),
    long_description_content_type="text/markdown",
    Homepage="https://github.com/not-lain/pxia",
    url="https://github.com/not-lain/pxia",
    Issues="https://github.com/not-lain/pxia/issues",
    authors=[{"name": "hafedh hichri", "email": "hhichri60@gmail.com"}],
    license="Apache 2.0 License",
    package_dir={"": "src"},
    packages=find_packages("src"),
    include_package_data=True,
    classifiers=[
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.9",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    use_scm_version=True,
    setup_requires=["setuptools_scm"],
    install_requires=required,
)
